#!/usr/bin/env python

import sys
import os
import urllib2
import json
sys.path.append(os.getcwd() + '/../../comm/')
import gzip
import StringIO
import datetime
from plugin_base import BaseSender
import cutils
from cutils import CommUtils


class CfsTcloudSender(BaseSender):
    def init(self):
        self.url = cutils.get_url('CfsTcloudSender','new_cfs_url','cfs_url')
        self.timeout = float(self.get_config('cfs_timeout'))/1000
        self.is_compress = int(self.get_config('is_compress'))
        self.newurl = self.url
        self.dnstime = 0
        self.dnscachetime = 300

    def send_data(self, json_data):
        try:
            curtime = datetime.datetime.now()
            if(self.dnstime ==0 or (curtime - self.dnstime).seconds > self.dnscachetime):
                tempurl = CommUtils.dns_parse(self.url)
                if cutils.check_net(tempurl, self.timeout):
                    self.newurl = tempurl
                self.dnstime = curtime
                self.logger().info("get CFSSender dns ipurl  : %s" % self.newurl)

            req = urllib2.Request(self.newurl)
            req.add_header('Content-Type', 'application/json')
            timeout = self.timeout
            data = json.dumps(json_data).lower()
            if self.is_compress == 1:
                try:
                    in_data = data
                    out = StringIO.StringIO()
                    f = gzip.GzipFile(fileobj=out, mode="wb")
                    f.write(in_data)
                    f.close()
                    data = out.getvalue()
                    req.add_header('Content-Encoding', 'gzip')
                    req.add_header('Content-Length', len(data))
                    self.logger().info("gzip compress before %d, after %d", len(in_data), len(data))
                except Exception as e:
                    self.logger().error(
                        "compress data error, error: %s, original data: %s", str(e), str(in_data))
            http_ret = urllib2.urlopen(req, data, timeout)
            response = http_ret.read()
            try:
                json_resp = json.loads(response)
                retcode = int(json_resp["returnCode"])
                if retcode != 0:
                    self.logger().error("cfs send error, retcode : %d, msg : %s, data : %s" %
                                        (retcode, json_resp["msg"], data))
                else:
                    self.logger().info("cfs send succ, data : %s" % str(data))
            except ValueError as e:
                self.logger().error("cfs send error, got a invalid json response : %s" % response)
        except urllib2.URLError as e:
            self.logger().error("send data error , error :%s, data : %s", str(e), data)
